@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(to_ascii to_latin1);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT ]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 my %ascii = (qw(
          A
@@ -196,7 +196,7 @@ sub to_latin1($) {
            ae
            (?!rleb)                   # e.g. Ahaerlebnis
            (?!rreg[^i])               #      Malariaerreger
-           (?=\w)                     # no  at the end of a word
+           (?=[\w])                     # no  at the end of a word
            (?!n\b)                    # even not if in plural
            (?!pid)                    # Choleraepidemie
            (?!in)                     # Kameraeinstellung
@@ -221,7 +221,7 @@ sub to_latin1($) {
               r[gz]|         # ...-srge, ...-rzte
               c[kh]|         # ...-scke
               n[dgk]e|         # ...-nderung, ...-nge, ... -snke
-              [lh]e          #sle, ... she
+              [lh]e          #sle, ... she, se
           )
          /ae/gx; 
         
@@ -256,7 +256,6 @@ sub to_latin1($) {
 	 }
     
 	if (/[Uu]e/) {
-        die $_ if //;
 	    # ue => , but take care for 'eue','ue', 'aue', 'que'
     	s/(?:(?<![oaeAEqQzZ]) | 
         	 (?<=nde) | 
@@ -291,7 +290,7 @@ sub to_latin1($) {
                            i?[ns](nen)?)?\b)/$1ue$2/gx;
         s/($prefix t)(?=s?t\b|risch)/$1 ? "$1ue" : "$1"/gxe;  # zurcktuest, grotuerisch 
         s/grnz/gruenz/g;
-        s/(?<!en)(s?)(?!\w)/ue$1/g;   # Im deutschen enden keine Worte auf , bis auf Ausnahmen
+        s/(?<!en)(s?)(?![\w])/ue$1/g;   # Im deutschen enden keine Worte auf , bis auf Ausnahmen
         s/z(?!rich)([rs][befhiosz])/zue$1/g; # Zuerzhlende != zricherisch
     
         s/([uU] e) (?=bt)/$mutation{$1}/egx;  # bte
@@ -839,6 +838,8 @@ sub to_latin1($) {
 
     s/\beinzng/einzueng/g;
     s/\bt(?=s?t\b)/tue/g;
+    s/Zei/Zeiss/g;          # I'm coming from Jena, Zeiss' hometown and that
+                             # really looks better :-)
     return $_;
 }
 
@@ -880,11 +881,14 @@ So there will be some words that will be always hard to retranslate from ascii
 to latin1 encoding. A known example is the difference between "Ma(einheit)" and
 "Masseentropie" or similar. Another examples are "flsse" and "Fle"
 or "(Der Schornstein) rue" and "Russe", "Geheimtuer(isch)" and "Geheimtr", 
-"anzu-ecken" and "anzcken". 
+"anzu-ecken" and "anzcken" or quite even a lonely "ss" or "". 
 Also, it's  hard to find the right spelling for the prefixes "miss-" or "mi-".
-In doubt I tried to use to more common word.
-I tried it with a huge list of german words, but please tell me if you find a 
-serious back-translation bug.
+In doubt I tried to use to more common word and in even still a doubt the
+program tries to be conservative, that means it prefers not to translate to an
+umlaut. Reason is that the text is still readable with one "ae","oe","ue" or
+"ss" to much, but a wrong "", "", "" or "" can make it very unreadable.
+
+I tried it with a huge list of german words, but please tell me if you find a bug.
 
 This module is intended for ANSI code that is e.g. different from windows coding.
 
